Logging (``taurex.log``)
========================

Logger
------

.. automodule:: taurex.log.logger
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: taurex.log
   :members:
   :undoc-members:
   :show-inheritance:
